@@ -42,6 +42,21 @@ ci_loader_conf = {
             ],
         },
     },
+    "azure": {
+        "commit": "BUILD_SOURCEVERSION",
+        "branch": "BUILD_SOURCEBRANCHNAME",
+        "pipeline_id": "SYSTEM_TIMELINEID",
+        "job_url": {
+            "format": "{0:s}/{1:s}/_build/results?buildId={2:s}&view=logs&j={3:s}&t={4:s}",
+            "variables": [
+                "SYSTEM_COLLECTIONURI",
+                "BUILD_REPOSITORY_NAME",
+                "BUILD_BUILDID",
+                "SYSTEM_JOBID",
+                "SYSTEM_TASKINSTANCEID",
+            ],
+        },
+    },
 }
 # this is a required function signature so there are going to be unused arguments
 # pylint: disable=unused-argument
